:mod:`euphorie.content.sector`
==============================

.. module:: euphorie.content.sector

.. autointerface:: ISector

.. autoclass:: Sector

.. autofunction:: getSurveys


Account support
---------------

.. autoclass:: SectorLocalRoleProvider
   :members:


Views
-----

.. autoclass:: View

.. autoclass:: ColourPreview

.. autoclass:: Settings

